==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property invalidFallbackBehavior What to do when JSON parsing fails. Defaults to evaluating up to the first parsing failure. Valid values are `EVALUATE_AS_STRING`, `MATCH` and `NO_MATCH`.
 * @property matchPattern The patterns to look for in the JSON body. You must specify exactly one setting: either `all` or `included_paths`. See [JsonMatchPattern](https://docs.aws.amazon.com/waf/latest/APIReference/API_JsonMatchPattern.html) for details.
 * @property matchScope The parts of the JSON to match against using the `match_pattern`. Valid values are `ALL`, `KEY` and `VALUE`.
 * @property oversizeHandling What to do if the body is larger than can be inspected. Valid values are `CONTINUE` (default), `MATCH` and `NO_MATCH`.
 */
public data class WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody(
    public val invalidFallbackBehavior: String? = null,
    public val matchPattern: WebAclRuleStatementXssMatchStatementFieldToMatchJsonBodyMatchPattern,
    public val matchScope: String,
    public val oversizeHandling: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody):
            WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody =
            WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody(
                invalidFallbackBehavior = javaType.invalidFallbackBehavior().map({ args0 -> args0 }).orElse(null),
                matchPattern = javaType.matchPattern().let({ args0 ->
                    com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementXssMatchStatementFieldToMatchJsonBodyMatchPattern.Companion.toKotlin(args0)
                }),
                matchScope = javaType.matchScope(),
                oversizeHandling = javaType.oversizeHandling().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property invalidFallbackBehavior What to do when JSON parsing fails. Defaults to evaluating up to the first parsing failure. Valid values are `EVALUATE_AS_STRING`, `MATCH` and `NO_MATCH`.
 * @property matchPattern The patterns to look for in the JSON body. You must specify exactly one setting: either `all` or `included_paths`. See [JsonMatchPattern](https://docs.aws.amazon.com/waf/latest/APIReference/API_JsonMatchPattern.html) for details.
 * @property matchScope The parts of the JSON to match against using the `match_pattern`. Valid values are `ALL`, `KEY` and `VALUE`.
 * @property oversizeHandling What to do if the body is larger than can be inspected. Valid values are `CONTINUE` (default), `MATCH` and `NO_MATCH`.
 */
public data class WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody(
    public val invalidFallbackBehavior: String? = null,
    public val matchPattern: WebAclRuleStatementXssMatchStatementFieldToMatchJsonBodyMatchPattern,
    public val matchScope: String,
    public val oversizeHandling: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody): WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody =
            WebAclRuleStatementXssMatchStatementFieldToMatchJsonBody(
                invalidFallbackBehavior = javaType.invalidFallbackBehavior().map({ args0 -> args0 }).orElse(null),
                matchPattern = javaType.matchPattern().let({ args0 ->
                    com.pulumi.aws.wafv2.kotlin.outputs.WebAclRuleStatementXssMatchStatementFieldToMatchJsonBodyMatchPattern.Companion.toKotlin(args0)
                }),
                matchScope = javaType.matchScope(),
                oversizeHandling = javaType.oversizeHandling().map({ args0 -> args0 }).orElse(null),
            )
    }
}
